<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Print</name>
    <message>
        <location filename="../PrintInit.js" line="+2"/>
        <source>&amp;Print</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wy&amp;drukuj...
Wy&amp;drukuj</translatorcomment>
        <translation>&amp;Drukuj</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Print current drawing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Drukuje aktualny rysunek</translation>
    </message>
</context>
</TS>
